from setuptools import setup, find_packages
import sys, os

version = '0.8'

setup(
    name="csefemerideak",
    version=version,
    description="",
    long_description="""\
""",
    classifiers=[],  # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    keywords="",
    author="",
    author_email="",
    url="",
    license="",
    packages=find_packages(exclude=["ez_setup", "examples", "tests"]),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        # -*- Extra requirements: -*-
        "django>=1.6,<1.9"
    ],
    entry_points="""
      # -*- Entry points: -*-
      """,
)
